pub struct Outputs<'t> {
pub truthy: bool,
pub available_captures: AvailableCaptures,
pub output: Output,
pub indent: &'t str,
}Expand description
Wrapper around Output that dereferences to it, but also offers a
truthy field, and implements Display to show a multi-line message
with both process status and its outputs.
Fields
truthy: boolWhether process exited with status 0 (or maybe in the future a set of status codes that represent success)
available_captures: AvailableCapturesoutput: Outputindent: &'t strPrefixed to output lines, “\t” by default