pub fn run<D: AsRef<Path>, P: AsRef<OsStr> + Debug, A: AsRef<OsStr> + Debug>(
in_directory: D,
cmd: P,
arguments: &[A],
set_env: &[(&str, &str)],
acceptable_status_codes: &[i32],
silencing: Capturing,
) -> Result<bool>Expand description
Run cmd with arguments and the env overridden with the
key-value pairs in set_env, wait for its completion. Returns an
error if cmd exited with a code that is not in
acceptable_status_codes. Returns true when 0 is in
acceptable_status_codes and cmd exited with status 0, false for
other accepted status codes. silencing specifies captures that
should be done, which are dropped unless there’s an error.